@@ -9,7 +9,7 @@
 # housekeeping
 ########################################################################
 
-package Object::Trampoline v1.40.0;
+package Object::Trampoline  v1.30.1;
 use v5.24;
 
 use Carp;
@@ -18,11 +18,6 @@ use Carp;
 # package variables
 ########################################################################
 
-# minimal sanity check for valid class name, used in both
-# O::T and O::T::U.
-
-my $pkg_rx      = qr{^ [_A-Za-z](?:\w*) (?:::\w+)* $}x;
-
 ########################################################################
 # AUTOLOAD is the only public interface
 ########################################################################
@@ -73,8 +68,8 @@ AUTOLOAD
 # housekeeping
 ########################################################################
 
-package Object::Trampoline::Use v1.40.0;
-use v5.24;
+package Object::Trampoline::Use;
+use v5.12;
 
 use Carp;
 
@@ -84,11 +79,11 @@ use Carp;
 
 *VERSION = \$Object::Trampoline::VERSION;
 
-our $AUTOLOAD = '';
-
 ########################################################################
 # AUTOLOAD is the only public interface
 ########################################################################
+    
+our $AUTOLOAD = '';
 
 AUTOLOAD
 {
@@ -145,15 +140,17 @@ AUTOLOAD
 # has an explicit method for handling the call; otherwise
 # use the name to dispatch the call.
 
-package Object::Trampoline::Bounce v1.40.0;
+package Object::Trampoline::Bounce;
 
-use v5.24;
+use v5.12;
 
 use Carp;
 
 use Scalar::Util    qw( blessed         );
 use Symbol          qw( qualify_to_ref  );
 
+# version is defined by the main package.
+
 *VERSION = \$Object::Trampoline::VERSION;
 
 our $AUTOLOAD = '';
@@ -185,6 +182,7 @@ AUTOLOAD
 }
 
 # re-route methods from UNIVERSAL through the bounce.
+# allows $trampoline->VERSION to do the right thing.
 
 for my $name ( keys %{ $::{ 'UNIVERSAL::' } } )
 {
@@ -197,6 +195,8 @@ for my $name ( keys %{ $::{ 'UNIVERSAL::' } } )
     };
 }
 
+
+
 # stub destroy dodges AUTOLOAD for unused trampolines.
 
 DESTROY {}
